// Copyright (c) 2002 David Muse
// See the COPYING file for more information.

	protected:
		long		timeoutsec;
		long		timeoutusec;
		unsigned int	retrywait;
		unsigned int	retrycount;
